@@ -304,7 +304,7 @@ AbstractOIDCAuthentication <- R6Class(
       if (length(private$endpoints$end_session_endpoint) == 1) {
         url = url_parse(private$endpoints$end_session_endpoint)
         response = req_perform(req_url_query(
-          req=request(url),
+          .req=request(url),
           id_token_hint = private$auth$id_token))
         
         if (response$status_code < 400) {
@@ -405,7 +405,7 @@ AbstractOIDCAuthentication <- R6Class(
     },
     
     isInteractive = function() {
-      return(if (is_jupyter()) TRUE else rlang::is_interactive())
+      return(if (is_jupyter()) FALSE else rlang::is_interactive())
     },
     
     decodeToken = function(access_token, token_part) {
@@ -640,4 +640,4 @@ OIDCAuthCodeFlow <- R6Class(
   else {
     return (NULL)
   }
-}
\ No newline at end of file
+}
