@@ -320,11 +320,13 @@ OpenEOClient <- R6Class(
         else {
           if (is.null(provider)) {
             providers = list_oidc_providers()
-            provider = providers[[1]]
-            if (is_null(provider)) {
-              message("Either a provider needs to be provided, or a username and password for basic authentication.")
-              return(invisible(self))
+            
+            # if it happens to be that the oidc provider list is empty then use a more meaningful error message
+            if (length(providers) == 0) {
+              stop("OIDC provider list from 'list_oidc_providers()' is empty. Please contact the back-end provider.")
+              # 
             }
+            provider = providers[[1]]
           }
           private$loginOIDC(provider = provider, config = config)
         }
@@ -365,9 +367,8 @@ OpenEOClient <- R6Class(
     
     getCapabilities = function() {
       if (is.null(private$capabilities)) {
-        endpoint = "/"
         tryCatch({
-          private$capabilities = private$GET(endpoint = endpoint)
+          private$capabilities = private$GET(endpoint = "")
             
           class(private$capabilities) = "OpenEOCapabilities"
         }, error = .capturedErrorToMessage)
