@@ -407,11 +407,15 @@ list_results = function(job, con=NULL) {
 download_results = function(job, folder, con=NULL) {
     con = .assure_connection(con)
     
-    if (length(job) != 1) {
+    if (missing(job) || is.null(job) || all(is.na(job))) {
       message("Parameter 'job' is not set.")
       return(invisible(NULL))
     }
     
+    if (missing(folder) || is.null(folder) || all(is.na(folder)) || length(folder) != 1) {
+      folder = tempdir()
+    }
+    
     if (!dir.exists(folder)) 
         dir.create(folder, recursive = TRUE)
     
@@ -517,6 +521,8 @@ describe_job = function(job,con=NULL) {
     }, error = .capturedErrorToMessage)
 }
 
+# to make a class definition for the returned lists
+setOldClass("Job")
 
 #' Delete a job
 #'
